@@ -1,6 +1,14 @@
+/*
+ * $Header: /home/barad-dur/vision/forsyth/schenney/sced-0.94/h/RCS/bezier.h,v 1.0 1997/05/06 20:40:56 schenney Exp $
+ *
+ * $Log: bezier.h,v $
+ * Revision 1.0  1997/05/06 20:40:56  schenney
+ * Initial revision
+ *
+ */
 /*
 **    ScEd: A Constraint Based Scene Editor.
-**    Copyright (C) 1994-1995  Stephen Chenney (stephen@cs.su.oz.au)
+**    Copyright (C) 1994-1998  Stephen Chenney (schenney@cs.berkeley.edu)
 **
 **    This program is free software; you can redistribute it and/or modify
 **    it under the terms of the GNU General Public License as published by
@@ -18,16 +26,13 @@
 */
 
 /*
-**	bezier.h: header for bezier patch functions.
+**  bezier.h: header for bezier patch functions.
 */
 
-extern void	Bezier_Create_Function(ObjectInstancePtr);
-extern void	Bezier_Destroy_Function(ObjectInstancePtr);
-extern void	Bezier_Copy_Hook(ObjectInstancePtr, ObjectInstancePtr);
-extern void	Bezier_Calculate_Vertices(ObjectInstancePtr, VectorPtr, int, int);
-extern void	Bezier_Calculate_Normals(ObjectInstancePtr, VectorPtr);
-extern Vector	Bezier_Calculate_Point(ObjectInstancePtr, double, double);
-extern void	Bezier_Calculate_Vertex_Normals(ObjectInstancePtr, Vector*, int,
-											Boolean);
+extern void Bezier_Create_Function(ObjectInstancePtr);
+extern void Bezier_Destroy_Function(ObjectInstancePtr);
+extern void Bezier_Copy_Hook(ObjectInstancePtr, ObjectInstancePtr);
+extern Vector   Bezier_Calculate_Point(ObjectInstancePtr, double, double);
+extern void Bezier_Calculate_Vertex_Normals(ObjectInstancePtr, Vector*, int);
 
-extern int	bezier_map[];
+extern int  bezier_map[];
