@@ -1,6 +1,14 @@
+/*
+ * $Header: /home/barad-dur/vision/forsyth/schenney/sced-0.94/h/RCS/hash.h,v 1.0 1997/05/06 20:42:12 schenney Exp $
+ *
+ * $Log: hash.h,v $
+ * Revision 1.0  1997/05/06 20:42:12  schenney
+ * Initial revision
+ *
+ */
 /*
 **    ScEd: A Constraint Based Scene Editor.
-**    Copyright (C) 1994-1995  Stephen Chenney (stephen@cs.su.oz.au)
+**    Copyright (C) 1994-1998  Stephen Chenney (schenney@cs.berkeley.edu)
 **
 **    This program is free software; you can redistribute it and/or modify
 **    it under the terms of the GNU General Public License as published by
@@ -19,24 +27,22 @@
 
 #define PATCHLEVEL 0
 /*
-**	sced: A Constraint Based Object Scene Editor
+**  sced: A Constraint Based Object Scene Editor
 **
-**	hash.h: Hash table functions for storing pointer mappings.
+**  hash.h: Hash table functions for storing pointer mappings.
 */
 
 typedef struct _HashEntry {
-	long	key;
-	void	*value;
-	struct _HashEntry	*next;
-	} HashEntry, *HashEntryPtr;
+    long    key;
+    void    *value;
+    struct _HashEntry   *next;
+    } HashEntry, *HashEntryPtr;
 
-typedef HashEntryPtr *HashTable;
-
-extern HashTable	Hash_New_Table();
-extern void	Hash_Insert(HashTable, unsigned long, void*);
-extern void	*Hash_Get_Value(HashTable, unsigned long);
-extern void	Hash_Free(HashTable);
-extern void	Hash_Clear(HashTable);
-extern void	*Hash_Delete(HashTable, unsigned long);
-extern void	*Hash_Traverse(HashTable, Boolean);
+extern HashTable    Hash_New_Table();
+extern void Hash_Insert(HashTable, unsigned long, void*);
+extern void *Hash_Get_Value(HashTable, unsigned long);
+extern void Hash_Free(HashTable);
+extern void Hash_Clear(HashTable);
+extern void *Hash_Delete(HashTable, unsigned long);
+extern void *Hash_Traverse(HashTable, Boolean);
 
