@@ -1,6 +1,14 @@
+/*
+ * $Header: /home/barad-dur/vision/forsyth/schenney/sced-0.94/h/RCS/sced.h,v 1.0 1997/05/06 20:42:37 schenney Exp $
+ *
+ * $Log: sced.h,v $
+ * Revision 1.0  1997/05/06 20:42:37  schenney
+ * Initial revision
+ *
+ */
 /*
 **    ScEd: A Constraint Based Scene Editor.
-**    Copyright (C) 1994-1995  Stephen Chenney (stephen@cs.su.oz.au)
+**    Copyright (C) 1994-1998  Stephen Chenney (schenney@cs.berkeley.edu)
 **
 **    This program is free software; you can redistribute it and/or modify
 **    it under the terms of the GNU General Public License as published by
@@ -19,11 +27,11 @@
 
 #define PATCHLEVEL 0
 /*
-**	sced: A Constraint Based Object Scene Editor
+**  sced: A Constraint Based Object Scene Editor
 **
-**	sced.h: Global header file.
+**  sced.h: Global header file.
 **
-**	Created: 05/03/94
+**  Created: 05/03/94
 */
 
 #include <stdio.h>
@@ -39,7 +47,7 @@
 #include <defs.h>
 #include <enum.h>
 #include <types.h>
-#include <extern.h>
-#include <proto.h>
+#include <globals.h>
+#include <protos.h>
 #include <macros.h>
 
