@@ -1,6 +1,14 @@
+/*
+ * $Header: /home/barad-dur/vision/forsyth/schenney/sced-0.94/h/RCS/triangle.h,v 1.0 1997/05/06 20:42:47 schenney Exp $
+ *
+ * $Log: triangle.h,v $
+ * Revision 1.0  1997/05/06 20:42:47  schenney
+ * Initial revision
+ *
+ */
 /*
 **    ScEd: A Constraint Based Scene Editor.
-**    Copyright (C) 1994-1995  Stephen Chenney (stephen@cs.su.oz.au)
+**    Copyright (C) 1994-1998  Stephen Chenney (schenney@cs.berkeley.edu)
 **
 **    This program is free software; you can redistribute it and/or modify
 **    it under the terms of the GNU General Public License as published by
@@ -18,12 +26,10 @@
 */
 
 /*
-**	triangle.h: header for triangle functions.
+**  triangle.h: header for triangle functions.
 */
 
-extern void	Triangle_Create_Function(ObjectInstancePtr);
-extern void	Triangle_Destroy_Function(ObjectInstancePtr);
-extern void	Triangle_Copy_Hook(ObjectInstancePtr, ObjectInstancePtr);
-extern void	Triangle_Calculate_Vertices(ObjectInstancePtr, VectorPtr);
-extern void	Triangle_Calculate_Normal(ObjectInstancePtr, VectorPtr);
+extern void Triangle_Create_Function(ObjectInstancePtr);
+extern void Triangle_Destroy_Function(ObjectInstancePtr);
+extern void Triangle_Copy_Hook(ObjectInstancePtr, ObjectInstancePtr);
 
